### Name: multdrc
### Title: Fitting multiple dose-response curves
### Aliases: multdrc
### Keywords: models nonlinear

### ** Examples


## Fitting response 'rootl' to dose 'conc' in the dataset 'ryegrass' 
##  (type ?ryegrass to learn about the data set)
model1 <- multdrc(rootl~conc, data = ryegrass)
summary(model1)

## Fitting a 5-parameter logistic model
model2 <- multdrc(ryegrass, fct = l5())
summary(model2)

## Fitting a 4-parameter logistic model
##  with Box-Cox transformation
model3 <- multdrc(ryegrass, boxcox = TRUE)  
summary(model3)

## Example using 'varPower' argument 
##  modelling variance as power of mean
model4 <- multdrc(ryegrass, varPower = TRUE)
summary(model4)

## Example using 'logDose' argument
logdose <- c(-8.045757, -7.568636, -7.086186, -6.607303, -6.130768, -5.653647, -5.180456, -4.698970)
response <- c(7.941, 16.619, 11.021, 19.767, 30.487, 64.434, 74.422, 52.472)
model5 <- multdrc(response ~ logdose, logDose=10)
plot(model5, conLevel=-9)  # the default level is too high

## Example using 'fctLink'
model6 <- multdrc(DryMatter ~ Dose,Herbicide, 
data=S.alba, fctList=list(l3(), l4()))
summary(model6)




